==> python-dateparser-0.7.6-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/dateparser/data/date_translation_data/dsb.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "dsb",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan",
        "januara"
    ],
    "february": [
        "februar",
        "feb",
        "februara"
    ],
    "march": [
        "měrc",
        "měr",
        "měrca"
    ],
    "april": [
        "apryl",
        "apr",
        "apryla"
    ],
    "may": [
        "maj",
        "maja"
    ],
    "june": [
        "junij",
        "jun",
        "junija"
    ],
    "july": [
        "julij",
        "jul",
        "julija"
    ],
    "august": [
        "awgust",
        "awg",
        "awgusta"
    ],
    "september": [
        "september",
        "sep",
        "septembra"
    ],
    "october": [
        "oktober",
        "okt",
        "oktobra"
    ],
    "november": [
        "nowember",
        "now",
        "nowembra"
    ],
    "december": [
        "december",
        "dec",
        "decembra"
    ],
    "monday": [
        "pónjeźele",
        "pón"
    ],
    "tuesday": [
        "wałtora",
        "wał"
    ],
    "wednesday": [
        "srjoda",
        "srj"
    ],
    "thursday": [
        "stwórtk",
        "stw"
    ],
    "friday": [
        "pětk",
        "pět"
    ],
    "saturday": [
        "sobota",
        "sob"
    ],
    "sunday": [
        "njeźela",
        "nje"
    ],
    "am": [
        "dopołdnja"
    ],
    "pm": [
        "wótpołdnja"
    ],
    "year": [
        "lěto",
        "l"
    ],
    "month": [
        "mjasec",
        "mjas"
    ],
    "week": [
        "tyźeń",
        "tyź"
    ],
    "day": [
        "źeń",
        "ź"
    ],
    "hour": [
        "góźina",
        "góź",
        "g"
    ],
    "minute": [
        "minuta",
        "min",
        "m"
    ],
    "second": [
        "sekunda",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "łoni"
        ],
        "0 year ago": [
            "lětosa"
        ],
        "in 1 year": [
            "znowa"
        ],
        "1 month ago": [
            "slědny mjasec"
        ],
        "0 month ago": [
            "ten mjasec"
        ],
        "in 1 month": [
            "pśiducy mjasec"
        ],
        "1 week ago": [
            "slědny tyźeń"
        ],
        "0 week ago": [
            "ten tyźeń"
        ],
        "in 1 week": [
            "pśiducy tyźeń"
        ],
        "1 day ago": [
            "cora"
        ],
        "0 day ago": [
            "źinsa"
        ],
        "in 1 day": [
            "witśe"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "za (\\d+) lěto",
            "za (\\d+) lět",
            "za (\\d+) l"
        ],
        "\\1 year ago": [
            "pśed (\\d+) lětom",
            "pśed (\\d+) lětami",
            "pśed (\\d+) l"
        ],
        "in \\1 month": [
            "za (\\d+) mjasec",
            "za (\\d+) mjasecow",
            "za (\\d+) mjas"
        ],
        "\\1 month ago": [
            "pśed (\\d+) mjasecom",
            "pśed (\\d+) mjasecami",
            "pśed (\\d+) mjas"
        ],
        "in \\1 week": [
            "za (\\d+) tyźeń",
            "za (\\d+) tyźenjow",
            "za (\\d+) tyź"
        ],
        "\\1 week ago": [
            "pśed (\\d+) tyźenjom",
            "pśed (\\d+) tyźenjami",
            "pśed (\\d+) tyź"
        ],
        "in \\1 day": [
            "za (\\d+) źeń",
            "za (\\d+) dnjow",
            "za (\\d+) dnj",
            "za (\\d+) ź"
        ],
        "\\1 day ago": [
            "pśed (\\d+) dnjom",
            "pśed (\\d+) dnjami",
            "pśed (\\d+) dnj",
            "pśed (\\d+) d"
        ],
        "in \\1 hour": [
            "za (\\d+) góźinu",
            "za (\\d+) góźin",
            "za (\\d+) góź",
            "za (\\d+) g"
        ],
        "\\1 hour ago": [
            "pśed (\\d+) góźinu",
            "pśed (\\d+) góźinami",
            "pśed (\\d+) góź",
            "pśed (\\d+) g"
        ],
        "in \\1 minute": [
            "za (\\d+) minutu",
            "za (\\d+) minutow",
            "za (\\d+) min",
            "za (\\d+) m"
        ],
        "\\1 minute ago": [
            "pśed (\\d+) minutu",
            "pśed (\\d+) minutami",
            "pśed (\\d+) min",
            "pśed (\\d+) m"
        ],
        "in \\1 second": [
            "za (\\d+) sekundu",
            "za (\\d+) sekundow",
            "za (\\d+) sek",
            "za (\\d+) s"
        ],
        "\\1 second ago": [
            "pśed (\\d+) sekundu",
            "pśed (\\d+) sekundami",
            "pśed (\\d+) sek",
            "pśed (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/dsb.py <==
info = {
    "name": "dsb",
    "date_order": "DMY",
    "january": [
        "jan",
        "januar",
        "januara"
    ],
    "february": [
        "feb",
        "februar",
        "februara"
    ],
    "march": [
        "měr",
        "měrc",
        "měrca"
    ],
    "april": [
        "apr",
        "apryl",
        "apryla"
    ],
    "may": [
        "maj",
        "maja"
    ],
    "june": [
        "jun",
        "junij",
        "junija"
    ],
    "july": [
        "jul",
        "julij",
        "julija"
    ],
    "august": [
        "awg",
        "awgust",
        "awgusta"
    ],
    "september": [
        "sep",
        "september",
        "septembra"
    ],
    "october": [
        "okt",
        "oktober",
        "oktobra"
    ],
    "november": [
        "now",
        "nowember",
        "nowembra"
    ],
    "december": [
        "dec",
        "december",
        "decembra"
    ],
    "monday": [
        "pón",
        "pónjeźele"
    ],
    "tuesday": [
        "wał",
        "wałtora"
    ],
    "wednesday": [
        "srj",
        "srjoda"
    ],
    "thursday": [
        "stw",
        "stwórtk"
    ],
    "friday": [
        "pět",
        "pětk"
    ],
    "saturday": [
        "sob",
        "sobota"
    ],
    "sunday": [
        "nje",
        "njeźela"
    ],
    "am": [
        "dopołdnja"
    ],
    "pm": [
        "wótpołdnja"
    ],
    "year": [
        "l",
        "lěto"
    ],
    "month": [
        "mjas",
        "mjasec"
    ],
    "week": [
        "tyź",
        "tyźeń"
    ],
    "day": [
        "ź",
        "źeń"
    ],
    "hour": [
        "g",
        "góź",
        "góźina"
    ],
    "minute": [
        "m",
        "min",
        "minuta"
    ],
    "second": [
        "s",
        "sek",
        "sekunda"
    ],
    "relative-type": {
        "0 day ago": [
            "źinsa"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "ten mjasec"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "ten tyźeń"
        ],
        "0 year ago": [
            "lětosa"
        ],
        "1 day ago": [
            "cora"
        ],
        "1 month ago": [
            "slědny mjasec"
        ],
        "1 week ago": [
            "slědny tyźeń"
        ],
        "1 year ago": [
            "łoni"
        ],
        "in 1 day": [
            "witśe"
        ],
        "in 1 month": [
            "pśiducy mjasec"
        ],
        "in 1 week": [
            "pśiducy tyźeń"
        ],
        "in 1 year": [
            "znowa"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "pśed (\\d+) d",
            "pśed (\\d+) dnj",
            "pśed (\\d+) dnjami",
            "pśed (\\d+) dnjom"
        ],
        "\\1 hour ago": [
            "pśed (\\d+) g",
            "pśed (\\d+) góź",
            "pśed (\\d+) góźinami",
            "pśed (\\d+) góźinu"
        ],
        "\\1 minute ago": [
            "pśed (\\d+) m",
            "pśed (\\d+) min",
            "pśed (\\d+) minutami",
            "pśed (\\d+) minutu"
        ],
        "\\1 month ago": [
            "pśed (\\d+) mjas",
            "pśed (\\d+) mjasecami",
            "pśed (\\d+) mjasecom"
        ],
        "\\1 second ago": [
            "pśed (\\d+) s",
            "pśed (\\d+) sek",
            "pśed (\\d+) sekundami",
            "pśed (\\d+) sekundu"
        ],
        "\\1 week ago": [
            "pśed (\\d+) tyź",
            "pśed (\\d+) tyźenjami",
            "pśed (\\d+) tyźenjom"
        ],
        "\\1 year ago": [
            "pśed (\\d+) l",
            "pśed (\\d+) lětami",
            "pśed (\\d+) lětom"
        ],
        "in \\1 day": [
            "za (\\d+) dnj",
            "za (\\d+) dnjow",
            "za (\\d+) ź",
            "za (\\d+) źeń"
        ],
        "in \\1 hour": [
            "za (\\d+) g",
            "za (\\d+) góź",
            "za (\\d+) góźin",
            "za (\\d+) góźinu"
        ],
        "in \\1 minute": [
            "za (\\d+) m",
            "za (\\d+) min",
            "za (\\d+) minutow",
            "za (\\d+) minutu"
        ],
        "in \\1 month": [
            "za (\\d+) mjas",
            "za (\\d+) mjasec",
            "za (\\d+) mjasecow"
        ],
        "in \\1 second": [
            "za (\\d+) s",
            "za (\\d+) sek",
            "za (\\d+) sekundow",
            "za (\\d+) sekundu"
        ],
        "in \\1 week": [
            "za (\\d+) tyź",
            "za (\\d+) tyźenjow",
            "za (\\d+) tyźeń"
        ],
        "in \\1 year": [
            "za (\\d+) l",
            "za (\\d+) lět",
            "za (\\d+) lěto"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
